@@ -53,7 +53,7 @@ def init(args):
         return
 
     # TODO fill out the .nwborg
-    init_org = SAPOFTO('.nwborglab')
+    init_org = SAPOFTO.SAPOFTO('.nwborglab')
     content = ''
     with open('.nwborglabsrc.org', 'r') as f: # TODO replace this with where the package will be
         content = f.read()
